CUTLASS 2.4 (Implicit GEMM convolution) (#147)
CUTLASS 2.4 (Implicit GEMM Convolution) Co-authored-by: Manish Gupta <manigupta@nvidia.com>, Haicheng Wu <haichengw@nvidia.com>, Dustyn Blasig <dblasig@nvidia.com>, Andrew Kerr <akerr@nvidia.com>
This commit is contained in:
@@ -81,7 +81,7 @@ __global__ void kernel_gemm_threadblock_tensor_op_multiplicand_store(
|
||||
}
|
||||
}
|
||||
|
||||
// Use iterator to scatter results
|
||||
// Use iterator to store results
|
||||
Iterator iter(ref_output, threadIdx.x);
|
||||
iter.store(frag);
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user